@@ -1,6 +1,6 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2017 Norbert Truchsess <norbert.truchsess@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "ui_IMainWindow.h"
 #include <QDir>
 #include <QMainWindow>
+#include <QPointer>
 
 class CMapList;
 class CDemList;
@@ -36,6 +37,7 @@ class CToolBarConfig;
 class CGeoSearchWeb;
 struct SGisLine;
 class CWptIconManager;
+class CHelp;
 
 class CMainWindow : public QMainWindow, private Ui::IMainWindow
 {
@@ -108,6 +110,7 @@ public:
     }
 
     void zoomCanvasTo(const QRectF rect);
+    void resetMouse();
     /**
        @brief Read the elevation from DEM data attached to the currently visible canvas for a given location
        @param pos   a position in units of [rad]
@@ -148,6 +151,7 @@ public slots:
     void slotLinkActivated(const QUrl& url);
 
 protected:
+    bool eventFilter(QObject *obj, QEvent *event) override;
 #ifdef WIN32
     bool CMainWindow::nativeEvent(const QByteArray & eventType, void * message, long * result);
 #endif // WIN32
@@ -157,7 +161,7 @@ protected:
 
 private slots:
     void slotAbout();
-    void slotHelp();
+    void slotWiki();
     void slotQuickstart();
     void slotAddCanvas();
     void slotCloneCanvas();
@@ -197,6 +201,8 @@ private slots:
     void slotGeoSearchConfigChanged();
     void slotDockFloating(bool floating);
     void slotRenameView();
+    void slotHelp();
+
 private:
     friend int main(int argc, char ** argv);
     CMainWindow();
@@ -246,6 +252,8 @@ private:
     bool menuVisible = false;
 
     static QMutex mutex;
+
+    QPointer<CHelp> help;
 };
 
 #endif //CMAINWINDOW_H
