@@ -1,6 +1,7 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2017 Norbert Truchsess <norbert.truchsess@t-online.de>
+    Copyright (C) 2019 Henri Hornburg <hrnbg@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -112,6 +113,9 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionGroupSort->setExclusive(true);
     actionSortByTime    = addSortAction(this, actionGroupSort, "://icons/32x32/Time.png", tr("Sort by Time"), IGisProject::eSortFolderTime);
     actionSortByName    = addSortAction(this, actionGroupSort, "://icons/32x32/SortName.png", tr("Sort by Name"), IGisProject::eSortFolderName);
+    actionSortByRating  = addSortAction(this, actionGroupSort, "://icons/32x32/Tag.png", tr("Sort by Rating"), IGisProject::eSortFolderRating);
+    actionFilterProject = addAction(QIcon("://icons/32x32/Filter.png"), tr("Filter Project"), this, SLOT(slotAddProjectFilter()));
+    actionFilterProject->setCheckable(true);
     actionAutoSave      = addAction(QIcon("://icons/32x32/AutoSave.png"), tr("Autom. Save"), this, SLOT(slotAutoSaveProject(bool)));
     actionAutoSave->setCheckable(true);
     actionUserFocusPrj  = addAction(QIcon("://icons/32x32/Focus.png"), tr("Active Project"), this, SLOT(slotUserFocusPrj(bool)));
@@ -129,6 +133,7 @@ CGisListWks::CGisListWks(QWidget *parent)
 
     // common to all items actions
     actionEditDetails   = addAction(QIcon("://icons/32x32/EditDetails.png"), tr("Edit..."), this, SLOT(slotEditItem()));
+    actionTagItem       = addAction(QIcon("://icons/32x32/Tag.png"), tr("Set Tags"), this, SLOT(slotTagItem()));
     actionCopyItem      = addAction(QIcon("://icons/32x32/Copy.png"), tr("Copy to..."), this, SLOT(slotCopyItem()));
     actionDelete        = addAction(QIcon("://icons/32x32/DeleteOne.png"), tr("Delete"), this, SLOT(slotDeleteItem()));
 
@@ -173,7 +178,7 @@ CGisListWks::CGisListWks(QWidget *parent)
 
     // several GIS items related actions
     actionRteFromWpt    = addAction(QIcon("://icons/32x32/Route.png"), tr("Create Route..."), this, SLOT(slotRteFromWpt()));
-    actionEditPrxWpt=  addAction(QIcon("://icons/32x32/WptEditProx.png"), tr("Change Proximity..."), this, SLOT(slotEditPrxWpt()));
+    actionEditPrxWpt =  addAction(QIcon("://icons/32x32/WptEditProx.png"), tr("Change Proximity..."), this, SLOT(slotEditPrxWpt()));
 
     connect(qApp, &QApplication::aboutToQuit, this, &CGisListWks::slotSaveWorkspace);
     connect(this, &CGisListWks::customContextMenuRequested, this, &CGisListWks::slotContextMenu);
@@ -504,7 +509,7 @@ void CGisListWks::dropEvent( QDropEvent  * e )
         return;
     }
 
-    int lastResult = CSelectCopyAction::eResultNone;
+    CSelectCopyAction::result_e lastResult = CSelectCopyAction::eResultNone;
 
     // go on with item insertion
     /*
@@ -527,7 +532,7 @@ void CGisListWks::dropEvent( QDropEvent  * e )
     {
         // calc. index offset (below/above item)
         QRect r = visualItemRect(itemAt(e->pos()));
-        int y1 = r.top() + r.height()/2;
+        int y1 = r.top() + r.height() / 2;
         int y2 = e->pos().y();
         int off = y2 > y1 ? 1 : 0;
 
@@ -994,6 +999,8 @@ void CGisListWks::showMenuProjectWks(const QPoint& p)
     menu.addSeparator();
     menu.addAction(actionSortByTime);
     menu.addAction(actionSortByName);
+    menu.addAction(actionSortByRating);
+    menu.addAction(actionFilterProject);
     menu.addSeparator();
     menu.addAction(actionAutoSave);
     menu.addAction(actionUserFocusPrj);
@@ -1038,6 +1045,7 @@ void CGisListWks::showMenuItemTrk(const QPoint &p, const IGisItem::key_t& key)
 
     QMenu menu(this);
     menu.addAction(actionEditDetails);
+    menu.addAction(actionTagItem);
     menu.addAction(actionCopyItem);
     menu.addSeparator();
     menu.addAction(actionFocusTrk);
@@ -1061,6 +1069,7 @@ void CGisListWks::showMenuItemWpt(const QPoint &p, CGisItemWpt * wpt)
 
     QMenu menu(this);
     menu.addAction(actionEditDetails);
+    menu.addAction(actionTagItem);
     menu.addAction(actionCopyItem);
     menu.addSeparator();
     menu.addAction(actionBubbleWpt);
@@ -1085,6 +1094,7 @@ void CGisListWks::showMenuItemRte(const QPoint &p)
 
     QMenu menu(this);
     menu.addAction(actionEditDetails);
+    menu.addAction(actionTagItem);
     menu.addAction(actionCopyItem);
     menu.addSeparator();
     menu.addAction(actionFocusRte);
@@ -1105,6 +1115,7 @@ void CGisListWks::showMenuItemOvl(const QPoint &p)
 
     QMenu menu(this);
     menu.addAction(actionEditDetails);
+    menu.addAction(actionTagItem);
     menu.addAction(actionCopyItem);
     menu.addSeparator();
     menu.addAction(actionEditArea);
@@ -1120,6 +1131,7 @@ void CGisListWks::showMenuItem(const QPoint &p, const QList<IGisItem::key_t>& ke
     QAction * action;
 
     QMenu menu(this);
+    menu.addAction(actionTagItem);
     menu.addAction(actionCopyItem);
     menu.addSection(tr("Waypoints"));
     menu.addAction(actionRteFromWpt);
@@ -1192,6 +1204,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
             else
             {
                 actionGroupSort->setEnabled(false);
+                actionFilterProject->setEnabled(false);
                 actionSyncWksDev->setEnabled(IDevice::count());
                 actionSyncDB->setEnabled(project->getType() == IGisProject::eTypeDb);
                 actionAutoSave->setVisible(false);
@@ -1228,7 +1241,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
             actionRteFromWpt->setEnabled(keysWpt.count() > 1);
             actionEditPrxWpt->setEnabled(hasWpts);
             actionCombineTrk->setEnabled(keysTrk.count() > 1);
-            actionEleWptTrk->setEnabled(hasWpts|hasTrks);
+            actionEleWptTrk->setEnabled(hasWpts | hasTrks);
             showMenuItem(p, keysTrk, keysWpt);
             return;
         }
@@ -1266,10 +1279,17 @@ void CGisListWks::slotContextMenu(const QPoint& point)
                     case IGisProject::eSortFolderTime:
                         actionSortByTime->setChecked(true);
                         break;
+
+                    case IGisProject::eSortFolderRating:
+                        actionSortByRating->setChecked(true);
+                        break;
                     }
 
                     blockSorting = false;
 
+                    actionFilterProject->setEnabled(true);
+                    actionFilterProject->setChecked(project->getProjectFilterItem() != nullptr);
+
                     bool hasUserFocus = project->hasUserFocus();
 
                     actionAutoSave->setVisible(true);
@@ -1416,7 +1436,7 @@ void CGisListWks::slotCloseProject()
 
 void CGisListWks::slotCloseAllProjects()
 {
-    int res = QMessageBox::question(this, tr("Close all projects..."), tr("This will remove all projects from the workspace."), QMessageBox::Ok|QMessageBox::Abort, QMessageBox::Ok);
+    int res = QMessageBox::question(this, tr("Close all projects..."), tr("This will remove all projects from the workspace."), QMessageBox::Ok | QMessageBox::Abort, QMessageBox::Ok);
     if(res != QMessageBox::Ok)
     {
         return;
@@ -1443,7 +1463,7 @@ void CGisListWks::slotDeleteProject()
         {
             {
                 CCanvasCursorLock cursorLock(Qt::ArrowCursor, __func__);
-                int res = QMessageBox::question(CMainWindow::getBestWidgetForParent(), tr("Delete project..."), tr("Do you really want to delete %1?").arg(project->getFilename()), QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok);
+                int res = QMessageBox::question(CMainWindow::getBestWidgetForParent(), tr("Delete project..."), tr("Do you really want to delete %1?").arg(project->getFilename()), QMessageBox::Ok | QMessageBox::No, QMessageBox::Ok);
 
                 if(res != QMessageBox::Ok)
                 {
@@ -1567,6 +1587,7 @@ void CGisListWks::slotItemDoubleClicked(QTreeWidgetItem * item, int )
         IGisProject * project = gisItem->getParentProject();
         if (project != nullptr && project->isVisible())
         {
+            CMainWindow::self().resetMouse();
             CMainWindow::self().zoomCanvasTo(gisItem->getBoundingRect());
             CGisWorkspace::self().focusTrkByKey(true, gisItem->getKey());
         }
@@ -1595,22 +1616,16 @@ void CGisListWks::slotEditItem()
     }
 }
 
+void CGisListWks::slotTagItem()
+{
+    CGisListWksEditLock lock(false, IGisItem::mutexItems);
+    CGisWorkspace::self().tagItemsByKey(selectedItems2Keys<IGisItem>());
+}
+
 void CGisListWks::slotDeleteItem()
 {
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
-
-    QList<QTreeWidgetItem*> items       = selectedItems();
-    QList<IGisItem::key_t>  keys;
-    for(QTreeWidgetItem * item : items)
-    {
-        IGisItem * gisItem = dynamic_cast<IGisItem*>(item);
-        if(gisItem != nullptr)
-        {
-            keys << gisItem->getKey();
-        }
-    }
-
-    CGisWorkspace::self().delItemsByKey(keys);
+    CGisWorkspace::self().delItemsByKey(selectedItems2Keys<IGisItem>());
 }
 
 void CGisListWks::slotCopyItem()
@@ -1626,18 +1641,7 @@ void CGisListWks::slotCopyItem()
      * later used to retrieve the item on the workspace via CGisWorkspace::getItemByKey()
      * again. This is always safe.
      */
-    QList<QTreeWidgetItem*> items = selectedItems();
-    QList<IGisItem::key_t>  keys;
-    for(QTreeWidgetItem * item : items)
-    {
-        IGisItem * gisItem = dynamic_cast<IGisItem*>(item);
-        if(gisItem != nullptr)
-        {
-            keys << gisItem->getKey();
-        }
-    }
-
-    CGisWorkspace::self().copyItemsByKey(keys);
+    CGisWorkspace::self().copyItemsByKey(selectedItems2Keys<IGisItem>());
 }
 
 void CGisListWks::slotProjWpt()
@@ -1753,16 +1757,7 @@ void CGisListWks::slotCombineTrk()
 {
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
 
-    QList<IGisItem::key_t>  keys;
-    QList<QTreeWidgetItem*> items = selectedItems();
-    for(QTreeWidgetItem * item : items)
-    {
-        CGisItemTrk * gisItem = dynamic_cast<CGisItemTrk*>(item);
-        if(gisItem)
-        {
-            keys << gisItem->getKey();
-        }
-    }
+    const QList<IGisItem::key_t>& keys = selectedItems2Keys<CGisItemTrk>();
 
     if(!keys.isEmpty())
     {
@@ -2081,6 +2076,15 @@ void CGisListWks::slotSyncDevWks()
     }
 }
 
+void CGisListWks::slotAddProjectFilter()
+{
+    //Since we only allow one Item to be selected at a time
+    IGisProject * project = dynamic_cast<IGisProject*>(selectedItems()[0]);
+    if(project != nullptr)
+    {
+        project->filterProject(actionFilterProject->isChecked());
+    }
+}
 
 bool CGisListWks::event(QEvent * e)
 {
@@ -2122,6 +2126,7 @@ bool CGisListWks::event(QEvent * e)
                 {
                     delete project;
                 }
+                project->setWorkspaceFilter(CGisWorkspace::self().getCurrentSearch());
             }
             e->accept();
             emit sigChanged();
@@ -2259,15 +2264,7 @@ void CGisListWks::slotRteFromWpt()
 {
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
 
-    QList<IGisItem::key_t> keys;
-    for(QTreeWidgetItem * item : selectedItems())
-    {
-        CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(item);
-        if(nullptr != wpt)
-        {
-            keys << wpt->getKey();
-        }
-    }
+    const QList<IGisItem::key_t>& keys = selectedItems2Keys<CGisItemWpt>();
 
     if(!keys.isEmpty())
     {
@@ -2279,15 +2276,7 @@ void CGisListWks::slotEditPrxWpt()
 {
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
 
-    QList<IGisItem::key_t> keys;
-    for(QTreeWidgetItem * item : selectedItems())
-    {
-        CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(item);
-        if(nullptr != wpt)
-        {
-            keys << wpt->getKey();
-        }
-    }
+    const QList<IGisItem::key_t>& keys = selectedItems2Keys<CGisItemWpt>();
 
     if(!keys.isEmpty())
     {
@@ -2318,7 +2307,6 @@ void CGisListWks::slotSetSortMode(IGisProject::sorting_folder_e mode, bool check
         return;
     }
 
-
     IGisProject * project = dynamic_cast<IGisProject*>(currentItem());
     if(project != nullptr)
     {
@@ -2366,35 +2354,11 @@ void CGisListWks::slotSymWpt()
     {
         return;
     }
-
-    QList<IGisItem::key_t> keys;
-    for(QTreeWidgetItem * item : selectedItems())
-    {
-        CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(item);
-        if(wpt == nullptr)
-        {
-            continue;
-        }
-
-        keys << wpt->getKey();
-    }
-
-    CGisWorkspace::self().changeWptSymByKey(keys, iconName);
+    CGisWorkspace::self().changeWptSymByKey(selectedItems2Keys<CGisItemWpt>(), iconName);
 }
 
 void CGisListWks::slotEleWptTrk()
 {
-    QList<IGisItem::key_t> keys;
-    for(QTreeWidgetItem * item : selectedItems())
-    {
-        IGisItem * gisItem = dynamic_cast<IGisItem*>(item);
-        if(gisItem != nullptr)
-        {
-            keys << gisItem->getKey();
-            continue;
-        }
-    }
-
-    CGisWorkspace::self().addEleToWptTrkByKey(keys);
+    CGisWorkspace::self().addEleToWptTrkByKey(selectedItems2Keys<IGisItem>());
 }
 
