@@ -1,6 +1,6 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2017 Norbert Truchsess <norbert.truchsess@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "device/IDevice.h"
 #include "gis/CGisDatabase.h"
 #include "gis/CGisDraw.h"
+#include "gis/CGisItemRate.h"
 #include "gis/CGisWorkspace.h"
 #include "gis/db/CDBProject.h"
 #include "gis/db/CSelectDBFolder.h"
@@ -54,44 +55,47 @@
 CGisWorkspace * CGisWorkspace::pSelf = nullptr;
 
 CGisWorkspace::CGisWorkspace(QMenu *menuProject, QWidget *parent)
-    : QWidget(parent)
+    : QWidget(parent), currentSearch("")
 {
     pSelf = this;
     setupUi(this);
 
-    lineFilter->addAction(actionClearFilter, QLineEdit::TrailingPosition);
-    lineFilter->addAction(actionHelp, QLineEdit::TrailingPosition);
-    lineFilter->addAction(actionSetupFilter, QLineEdit::LeadingPosition);
-
     treeWks->setExternalMenu(menuProject);
 
     SETTINGS;
     treeWks->header()->restoreState(cfg.value("Workspace/treeWks/state", treeWks->header()->saveState()).toByteArray());
+
+    tags_hidden_e tagsHidden = (tags_hidden_e)cfg.value("Workspace/treeWks/tagsHidden", eTagsHiddenUnknown).toInt();
+    // Limit the column width to half the table width to avoid the name column to be pushed out the window.
+    if(tagsHidden == eTagsHiddenUnknown || treeWks->columnWidth(CGisListWks::eColumnRating) > 0.4 * this->width())
+    {
+        treeWks->setColumnWidth(CGisListWks::eColumnRating, 0.2 * this->width());
+    }
+
+    //Only show tags if they are explcitely not hidden
+    setTagsHidden(tagsHidden != eTagsHiddenFalse);
+
+
     CSearch::setSearchMode(CSearch::search_mode_e(cfg.value("Workspace/projects/filterMode", CSearch::getSearchMode()).toInt()));
     CSearch::setCaseSensitivity(Qt::CaseSensitivity(cfg.value("Workspace/projects/CaseSensitivity", CSearch::getCaseSensitivity()).toInt()));
 
     connect(treeWks, &CGisListWks::sigChanged, this, &CGisWorkspace::sigChanged);
     connect(sliderOpacity, &QSlider::valueChanged, this, &CGisWorkspace::slotSetGisLayerOpacity);
-    connect(lineFilter, &QLineEdit::textChanged, this, &CGisWorkspace::slotSearch);
-    connect(actionSetupFilter, &QAction::triggered, this, &CGisWorkspace::slotSetupSearch);
+    connect(lineFilter, &CSearchLineEdit::sigWorkspaceSearchChanged, this, &CGisWorkspace::slotSearch);
     connect(treeWks, &CGisListWks::itemPressed, this, &CGisWorkspace::slotWksItemPressed);
     connect(treeWks, &CGisListWks::itemSelectionChanged, this, &CGisWorkspace::slotWksItemSelectionChanged);
     connect(treeWks, &CGisListWks::sigItemDeleted, this, &CGisWorkspace::slotWksItemSelectionChanged);
-
-    connect(actionNameOnly, &QAction::triggered, this, &CGisWorkspace::slotSearchNameOnly);
-    connect(actionCompleteText, &QAction::triggered, this, &CGisWorkspace::slotSearchCompleteText);
-    connect(actionCaseSensitive, &QAction::triggered, this, &CGisWorkspace::slotCaseSensitive);
-    connect(actionHelp, &QAction::triggered, this, &CGisWorkspace::slotSearchHelp);
-
-    // [Issue #265] Delay the loading of the workspace to make sure the complete IUnit system
-    //              is up and running.
-    QTimer::singleShot(1000, treeWks, SLOT(slotLoadWorkspace()));
 }
 
 CGisWorkspace::~CGisWorkspace()
 {
     SETTINGS;
+    //To ensure backwards compatibility first it is saved wether the tags are hidden,
+    //then the column is made visible and then the header is saved. This way the name column is in no case hidden.
+    cfg.setValue("Workspace/treeWks/tagsHidden", areTagsHidden() ? eTagsHiddenTrue : eTagsHiddenFalse);
+    setTagsHidden(false);
     cfg.setValue("Workspace/treeWks/state", treeWks->header()->saveState());
+
     cfg.setValue("Workspace/projects/filterMode", CSearch::getSearchMode());
     cfg.setValue("Workspace/projects/CaseSensitivity", CSearch::getCaseSensitivity());
     /*
@@ -102,6 +106,13 @@ CGisWorkspace::~CGisWorkspace()
     delete treeWks;
 }
 
+void CGisWorkspace::slotLateInit()
+{
+    // [Issue #265] Delay the loading of the workspace to make sure the complete IUnit system
+    //              is up and running.
+    QTimer::singleShot(1000, treeWks, SLOT(slotLoadWorkspace()));
+}
+
 void CGisWorkspace::setOpacity(qreal val)
 {
     sliderOpacity->setValue(val * 100);
@@ -132,6 +143,11 @@ void CGisWorkspace::loadGisProject(const QString& filename)
         }
 
         treeWks->blockSignals(false);
+
+        if(item != nullptr)
+        {
+            item->setWorkspaceFilter(currentSearch);
+        }
     }
 
     emit sigChanged();
@@ -140,7 +156,7 @@ void CGisWorkspace::loadGisProject(const QString& filename)
 
 void CGisWorkspace::slotSetGisLayerOpacity(int val)
 {
-    CCanvas::gisLayerOpacity = qreal(val)/100;
+    CCanvas::gisLayerOpacity = qreal(val) / 100;
     CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
     if(canvas != nullptr)
     {
@@ -148,21 +164,13 @@ void CGisWorkspace::slotSetGisLayerOpacity(int val)
     }
 }
 
-void CGisWorkspace::applySearch()
+void CGisWorkspace::slotSearch(const CSearch& currentSearch)
 {
-    slotSearch(lineFilter->text());
-}
-
-void CGisWorkspace::slotSearch(const QString& str)
-{
-    actionClearFilter->setIcon(str.isEmpty() ? QIcon("://icons/32x32/Filter.png") : QIcon("://icons/32x32/Cancel.png"));
-
+    this->currentSearch = currentSearch;
     {
         CCanvasCursorLock cursorLock(Qt::WaitCursor, __func__);
         QMutexLocker lock(&IGisItem::mutexItems);
 
-        CSearch currentSearch (str);
-
         const int N = treeWks->topLevelItemCount();
         for(int n = 0; n < N; n++)
         {
@@ -172,91 +180,13 @@ void CGisWorkspace::slotSearch(const QString& str)
                 continue;
             }
 
-            item->filter(currentSearch);
-            item->setExpanded(!str.isEmpty());
-        }
-
-        //test whether syntax errors occured and show error
-        if(currentSearch.getSyntaxError())
-        {
-            lineFilter->addAction(actionError, QLineEdit::TrailingPosition);
-            if(currentSearch.getSearchMode() == CSearch::eSearchModeName)
-            {
-                actionError->setToolTip(tr("Error parsing search.") + " " + tr("Continuing with search for match in names"));
-            }
-            else
-            {
-                actionError->setToolTip(tr("Error parsing search.") + " " + tr("Continuing with search for match in full text"));
-            }
-        }
-        else
-        {
-            lineFilter->removeAction(actionError);
-        }
-
-        if(currentSearch.isAutodetectedProperty())
-        {
-            lineFilter->addAction(actionAutoProperty, QLineEdit::TrailingPosition);
-            actionAutoProperty->setToolTip(tr("Automatically set the property, please make sure the results are correct."));
-        }
-        else
-        {
-            lineFilter->removeAction(actionAutoProperty);
+            item->setWorkspaceFilter(currentSearch);
+            item->setExpanded(!lineFilter->text().isEmpty());
         }
     }
-
     CCanvas::triggerCompleteUpdate(CCanvas::eRedrawGis);
 }
 
-void CGisWorkspace::slotSetupSearch()
-{
-    QMenu * menu = new QMenu(lineFilter);
-    menu->addSection(tr("Apply filter to"));
-    menu->addAction(actionNameOnly);
-    menu->addAction(actionCompleteText);
-    menu->addSection(tr("Case sensitivity"));
-    menu->addAction(actionCaseSensitive);
-
-    QActionGroup* actionGroup = new QActionGroup(menu);
-    actionGroup->addAction(actionNameOnly);
-    actionGroup->addAction(actionCompleteText);
-
-    switch(CSearch::getSearchMode())
-    {
-    case CSearch::eSearchModeName:
-        actionNameOnly->setChecked(true);
-        break;
-
-    case CSearch::eSearchModeText:
-        actionCompleteText->setChecked(true);
-        break;
-    }
-
-    if(CSearch::getCaseSensitivity() == Qt::CaseSensitive)
-    {
-        actionCaseSensitive->setChecked(true);
-    }
-    else
-    {
-        actionCaseSensitive->setChecked(false);
-    }
-    menu->move(lineFilter->parentWidget()->mapToGlobal(lineFilter->geometry().topLeft()));
-    menu->exec();
-}
-
-void CGisWorkspace::slotSearchHelp()
-{
-    if(explanationDlg == nullptr)
-    {
-        explanationDlg = new CSearchExplanationDialog(this);
-    }
-
-    if(!explanationDlg->isVisible())
-    {
-        explanationDlg->show();
-    }
-}
-
 void CGisWorkspace::slotSaveAll()
 {
     CCanvasCursorLock cursorLock(Qt::WaitCursor, __func__);
@@ -323,37 +253,6 @@ void CGisWorkspace::slotWksItemSelectionReset()
     }
 }
 
-void CGisWorkspace::slotSearchNameOnly(bool yes)
-{
-    if(yes)
-    {
-        CSearch::setSearchMode(CSearch::eSearchModeName);
-        applySearch();
-    }
-}
-
-void CGisWorkspace::slotSearchCompleteText(bool yes)
-{
-    if(yes)
-    {
-        CSearch::setSearchMode(CSearch::eSearchModeText);
-        applySearch();
-    }
-}
-
-void CGisWorkspace::slotCaseSensitive(bool yes)
-{
-    if(yes)
-    {
-        CSearch::setCaseSensitivity(Qt::CaseSensitive);
-    }
-    else
-    {
-        CSearch::setCaseSensitivity(Qt::CaseInsensitive);
-    }
-    applySearch();
-}
-
 void CGisWorkspace::slotActivityTrkByKey(const QList<IGisItem::key_t>& keys, trkact_t act)
 {
     if(keys.isEmpty())
@@ -458,7 +357,7 @@ IGisProject * CGisWorkspace::selectProject(bool forceSelect)
             CDBProject * p = nullptr;
             while(nullptr == p)
             {
-                QApplication::processEvents(QEventLoop::WaitForMoreEvents|QEventLoop::ExcludeUserInputEvents, 100);
+                QApplication::processEvents(QEventLoop::WaitForMoreEvents | QEventLoop::ExcludeUserInputEvents, 100);
                 p = dynamic_cast<CDBProject*>(treeWks->getProjectById(evt.idChild, db));
             }
             /*
@@ -774,9 +673,8 @@ void CGisWorkspace::copyItemByKey(const IGisItem::key_t &key)
     {
         return;
     }
-
-    int lastResult = CSelectCopyAction::eResultNone;
-    project->insertCopyOfItem(item, NOIDX, lastResult);
+    CSelectCopyAction::result_e actionForAll = CSelectCopyAction::eResultNone;
+    project->insertCopyOfItem(item, NOIDX, actionForAll);
 
 
     emit sigChanged();
@@ -792,7 +690,7 @@ void CGisWorkspace::copyItemsByKey(const QList<IGisItem::key_t> &keys)
         return;
     }
 
-    int lastResult = CSelectCopyAction::eResultNone;
+    CSelectCopyAction::result_e lastResult = CSelectCopyAction::eResultNone;
 
     project->blockUpdateItems(true);
     int cnt = 1;
@@ -1068,7 +966,7 @@ void CGisWorkspace::cutTrkByKey(const IGisItem::key_t& key)
     CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(getItemByKey(key));
     if(nullptr != trk && trk->cut())
     {
-        int res = QMessageBox::question(this, tr("Cut Track..."), tr("Do you want to delete the original track?"), QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok);
+        int res = QMessageBox::question(this, tr("Cut Track..."), tr("Do you want to delete the original track?"), QMessageBox::Ok | QMessageBox::No, QMessageBox::Ok);
         if(res == QMessageBox::Ok)
         {
             delete trk;
@@ -1337,14 +1235,14 @@ void CGisWorkspace::editPrxWpt(const QList<IGisItem::key_t>& keys)
     QMutexLocker lock(&IGisItem::mutexItems);
 
     QVariant var;
-    CInputDialog dlg(this, tr("Enter new proximity range."), var, QVariant(NOFLOAT), IUnit::self().baseunit);
+    CInputDialog dlg(this, tr("Enter new proximity range."), var, QVariant(NOFLOAT), IUnit::self().baseUnit);
     dlg.setOption(tr("Is no-go area"), false);
     if(dlg.exec() != QDialog::Accepted)
     {
         return;
     }
 
-    qreal proximity = var.toDouble()/IUnit::self().basefactor;
+    qreal proximity = var.toDouble() / IUnit::self().baseFactor;
     bool isNoGo = dlg.optionIsChecked();
     for(const IGisItem::key_t& key : keys)
     {
@@ -1469,3 +1367,57 @@ bool CGisWorkspace::findPolylineCloseBy(const QPointF& pt1, const QPointF& pt2,
 
     return !polyline.isEmpty();
 }
+
+bool CGisWorkspace::areTagsHidden() const
+{
+    return treeWks->isColumnHidden(CGisListWks::eColumnRating);
+}
+
+void CGisWorkspace::setTagsHidden(bool hidden)
+{
+    treeWks->setColumnHidden(CGisListWks::eColumnRating, hidden);
+}
+
+void CGisWorkspace::tagItemsByKey(const QList<IGisItem::key_t>& keys)
+{
+    QSet<QString> commonKeywords;
+
+    QList<IGisItem*> items;
+    bool firstItem = true;
+    qreal rating = 0;
+    for(const IGisItem::key_t& key : keys)
+    {
+        IGisItem * gisItem = getItemByKey(key);
+        if(gisItem != nullptr)
+        {
+            if(firstItem)
+            {
+                commonKeywords = gisItem->getKeywords();
+                rating = gisItem->getRating();
+                firstItem = false;
+            }
+            else
+            {
+                commonKeywords = commonKeywords.intersect(gisItem->getKeywords());
+            }
+
+            items << gisItem;
+        }
+    }
+
+    CGisItemRate dlg (this, commonKeywords, items.size() > 1 ? 0 : rating);
+    dlg.exec();
+
+    if(dlg.result() == QDialog::Accepted)
+    {
+        for(IGisItem * gisItem : items)
+        {
+            if(dlg.getRatingChanged())
+            {
+                gisItem->setRating(dlg.getRating());
+            }
+            gisItem->removeKeywords(dlg.getRemovedKeywords());
+            gisItem->addKeywords(dlg.getAddedKeywords());
+        }
+    }
+}
