@@ -1,6 +1,6 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2017 Norbert Truchsess <norbert.truchsess@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include "db/IDBFolder.h"
 #include "gis/IGisItem.h"
 #include "gis/rte/router/IRouter.h"
+#include "gis/search/CSearchLineEdit.h"
 
 
 class CGisDraw;
@@ -427,38 +428,38 @@ public:
 
     void setOpacity(qreal val);
 
-    void applySearch();
-
     bool findPolylineCloseBy(const QPointF& pt1, const QPointF& pt2, qint32 threshold, QPolygonF& polyline);
 
+    bool areTagsHidden() const;
+    void setTagsHidden(bool hidden);
+
+    void tagItemsByKey(const QList<IGisItem::key_t>& keys);
+
+    const CSearch& getCurrentSearch() const
+    {
+        return currentSearch;
+    }
+
 signals:
     void sigChanged();
 
 public slots:
+    void slotLateInit();
     void slotSaveAll();
     void slotWksItemSelectionReset();
     void slotActivityTrkByKey(const QList<IGisItem::key_t>& keys, trkact_t act);
 
 private slots:
     void slotSetGisLayerOpacity(int val);
-    void slotSearch(const QString& str);
-    void slotSetupSearch();
-    void slotSearchHelp();
+    void slotSearch(const CSearch& currentSearch);
 
     void slotWksItemSelectionChanged();
     void slotWksItemPressed(QTreeWidgetItem * item);
 
-    void slotSearchNameOnly(bool yes);
-    void slotSearchCompleteText(bool yes);
-
-    void slotCaseSensitive(bool yes);
-
 private:
     friend class CMainWindow;
     CGisWorkspace(QMenu * menuProject, QWidget * parent);
 
-    CSearchExplanationDialog* explanationDlg = nullptr;
-
     static CGisWorkspace * pSelf;
 
     /**
@@ -467,6 +468,14 @@ private:
         the mouse object to find items close by for highlight.
      */
     IGisItem::key_t keyWksSelection;
+    CSearch currentSearch;
+
+    enum tags_hidden_e
+    {
+        eTagsHiddenTrue,
+        eTagsHiddenFalse,
+        eTagsHiddenUnknown
+    };
 };
 
 #endif //CGISWORKSPACE_H
