@@ -1,5 +1,6 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2020 Henri Hornburg <hrnbg@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,6 +33,7 @@
 #include "GeoMath.h"
 #include "helpers/CDraw.h"
 #include "helpers/CSettings.h"
+#include "misc.h"
 #include "units/IUnit.h"
 
 #include <QtSql>
@@ -79,7 +81,7 @@ IGisItem::IGisItem(IGisProject *parent, type_e typ, int idx)
                 if(childType == eTypeTrk)
                 {
                     parent->removeChild(this);
-                    parent->insertChild(n+1, this);
+                    parent->insertChild(n + 1, this);
                     break;
                 }
             }
@@ -95,7 +97,7 @@ IGisItem::IGisItem(IGisProject *parent, type_e typ, int idx)
                 if( childType == eTypeRte || childType == eTypeTrk)
                 {
                     parent->removeChild(this);
-                    parent->insertChild(n+1, this);
+                    parent->insertChild(n + 1, this);
                     break;
                 }
             }
@@ -111,7 +113,7 @@ IGisItem::IGisItem(IGisProject *parent, type_e typ, int idx)
                 if(childType == eTypeWpt || childType == eTypeRte || childType == eTypeTrk)
                 {
                     parent->removeChild(this);
-                    parent->insertChild(n+1, this);
+                    parent->insertChild(n + 1, this);
                     break;
                 }
             }
@@ -127,7 +129,7 @@ IGisItem::IGisItem(IGisProject *parent, type_e typ, int idx)
                 if(childType == eTypeOvl || childType == eTypeWpt || childType == eTypeRte || childType == eTypeTrk)
                 {
                     parent->removeChild(this);
-                    parent->insertChild(n+1, this);
+                    parent->insertChild(n + 1, this);
                     break;
                 }
             }
@@ -336,7 +338,7 @@ void IGisItem::updateDecoration(quint32 enable, quint32 disable)
 
     // update project if necessary
     IGisProject * project = getParentProject();
-    if(project && (enable & (eMarkChanged|eMarkNotPart|eMarkNotInDB)))
+    if(project && (enable & (eMarkChanged | eMarkNotPart | eMarkNotInDB)))
     {
         project->setChanged();
     }
@@ -378,6 +380,25 @@ void IGisItem::updateDecoration(quint32 enable, quint32 disable)
     }
     setText(CGisListWks::eColumnDecoration, str);
     setToolTip(CGisListWks::eColumnDecoration, tt);
+
+    //Set Info column
+    if(!keywords.isEmpty())
+    {
+        QTreeWidgetItem::setIcon(CGisListWks::eColumnRating, QPixmap("://icons/32x32/Tag.png"));
+        setToolTip(CGisListWks::eColumnRating, QStringList(getKeywordsSorted()).join(", "));
+    }
+    else
+    {
+        QTreeWidgetItem::setIcon(CGisListWks::eColumnRating, QIcon());
+    }
+    if(rating > 0)
+    {
+        QTreeWidgetItem::setText(CGisListWks::eColumnRating, QString::number(rating));
+    }
+    else
+    {
+        QTreeWidgetItem::setText(CGisListWks::eColumnRating, "");
+    }
 }
 
 
@@ -592,7 +613,7 @@ bool IGisItem::setReadOnlyMode(bool readOnly)
     }
 
     // warn if item is external and read only
-    if(!(flags & (eFlagCreatedInQms|eFlagTainted)))
+    if(!(flags & (eFlagCreatedInQms | eFlagTainted)))
     {
         SETTINGS;
         bool doNotAsk = cfg.value("Dialog/Items/ReadOnly/doNotAsk", false).toBool();
@@ -603,7 +624,7 @@ bool IGisItem::setReadOnlyMode(bool readOnly)
 
             QCheckBox * checkBox = new QCheckBox(tr("Never ask again."), 0);
             QString msg = tr("<h3>%1</h3> This element is probably read-only because it was not created within QMapShack. Usually you should not want to change imported data. But if you think that is ok press 'Ok'.").arg(getName());
-            QMessageBox box(QMessageBox::Warning, tr("Read Only Mode..."), msg, QMessageBox::Ok|QMessageBox::Abort, CMainWindow::getBestWidgetForParent());
+            QMessageBox box(QMessageBox::Warning, tr("Read Only Mode..."), msg, QMessageBox::Ok | QMessageBox::Abort, CMainWindow::getBestWidgetForParent());
             box.setDefaultButton(QMessageBox::Ok);
             box.setCheckBox(checkBox);
             int res = box.exec();
@@ -683,7 +704,7 @@ void IGisItem::showIcon()
         displayIcon.fill(Qt::transparent);
         QPainter painter(&displayIcon);
         painter.drawPixmap(0, 0, icon);
-        painter.drawPixmap(width*0.4, height*0.4, QPixmap("://icons/48x48/NoGo.png").scaled(width*0.6, height*0.6, Qt::KeepAspectRatio, Qt::SmoothTransformation));
+        painter.drawPixmap(width * 0.4, height * 0.4, QPixmap("://icons/48x48/NoGo.png").scaled(width * 0.6, height * 0.6, Qt::KeepAspectRatio, Qt::SmoothTransformation));
     }
     else
     {
@@ -1037,3 +1058,54 @@ IGisItem * IGisItem::newGisItem(quint32 type, quint64 id, QSqlDatabase& db, IGis
 
     return item;
 }
+
+qreal IGisItem::getRating() const
+{
+    return rating;
+}
+
+void IGisItem::setRating(qreal rating)
+{
+    this->rating = rating;
+    updateHistory();
+}
+
+const QSet<QString> &IGisItem::getKeywords() const
+{
+    return keywords;
+}
+
+QList<QString> IGisItem::getKeywordsSorted() const
+{
+    QList<QString> sortedKeywords = keywords.toList();
+    std::sort(sortedKeywords.begin(), sortedKeywords.end(), sortByString);
+    return sortedKeywords;
+}
+
+void IGisItem::addKeywords(const QSet<QString> &otherKeywords)
+{
+    keywords.unite(otherKeywords);
+    updateHistory();
+}
+
+void IGisItem::removeKeywords(const QSet<QString> &otherKeywords)
+{
+    keywords.subtract(otherKeywords);
+    updateHistory();
+}
+
+const QString IGisItem::getRatingKeywordInfo() const
+{
+    QString str = "";
+    if(getRating() > 0)
+    {
+        str += "<br/>\n";
+        str += tr("Rating: ") + QString::number(getRating());
+    }
+    if(!getKeywordsSorted().isEmpty())
+    {
+        str += "<br/>\n";
+        str += tr("Keywords: ") + QStringList(getKeywordsSorted()).join(", ");
+    }
+    return str;
+}
