@@ -45,7 +45,7 @@ static QDateTime toDateTime(quint32 timestamp)
 {
     QDateTime dateTime;
     dateTime.setTime_t(sec1970to1990 + timestamp);
-    return dateTime;
+    return dateTime.toUTC();
 }
 
 static QString dateTimeAsString(quint32 timestamp)
