@@ -1,6 +1,6 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2019 Henri Hornburg hrnbg@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2019 Henri Hornburg <hrnbg@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ const QString IGisProject::rmc_ns    = "urn:net:trekbuddy:1.0:nmea:rmc";
 const QString IGisProject::ql_ns     = "http://www.qlandkarte.org/xmlschemas/v1.1";
 const QString IGisProject::gs_ns     = "http://www.groundspeak.com/cache/1/0";
 const QString IGisProject::tp1_ns    = "http://www.garmin.com/xmlschemas/TrackPointExtension/v1";
-const QString IGisProject::gpxdata_ns= "http://www.cluetrust.com/XML/GPXDATA/1/0";
+const QString IGisProject::gpxdata_ns = "http://www.cluetrust.com/XML/GPXDATA/1/0";
 
 
 static void readXml(const QDomNode& xml, const QString& tag, qint32& value)
@@ -489,7 +489,7 @@ QDomNode IGisProject::writeMetadata(QDomDocument& doc, bool strictGpx11)
                          + gpxtpx_ns + " http://www.garmin.com/xmlschemas/TrackPointExtensionv1.xsd "
                          + wptx1_ns  + " http://www.garmin.com/xmlschemas/WaypointExtensionv1.xsd "
                          + ql_ns     + " http://www.qlandkarte.org/xmlschemas/v1.1/ql-extensions.xsd "
-                         + gpxdata_ns+ " http://www.cluetrust.com/Schemas/gpxdata10.xsd";
+                         + gpxdata_ns + " http://www.cluetrust.com/Schemas/gpxdata10.xsd";
     }
     else
     {
@@ -622,16 +622,33 @@ void CGisItemWpt::save(QDomNode& gpx, bool strictGpx11)
 
 void CGisItemWpt::readGcExt(const QDomNode& xmlCache)
 {
-    geocache.service = eGC;
+    //Geocaches only have one link
+    if(wpt.links.first().uri.url(QUrl::RemovePath).contains("geocaching.com"))
+    {
+        geocache.service = eGcCom;
+    }
+    else if(wpt.links.first().uri.url(QUrl::RemovePath).contains("opencaching"))
+    {
+        geocache.service = eOc;
+    }
+    else if(wpt.links.first().uri.url(QUrl::RemovePath).contains("geocaching.su"))
+    {
+        geocache.service = eGcSu;
+    }
+    else
+    {
+        geocache.service = eUnknown;
+    }
+
     const QDomNamedNodeMap& attr = xmlCache.attributes();
     geocache.id = attr.namedItem("id").nodeValue().toInt();
 
     QDomNode geocacheAttributes = xmlCache.namedItem("groundspeak:attributes");
 
-    geocache.archived   = attr.namedItem("archived").nodeValue().toLocal8Bit() == "True";
-    geocache.available  = attr.namedItem("available").nodeValue().toLocal8Bit() == "True";
+    geocache.archived   = attr.namedItem("archived").nodeValue().toLocal8Bit().toLower() == "true";
+    geocache.available  = attr.namedItem("available").nodeValue().toLocal8Bit().toLower() == "true";
 
-    for(QDomNode xmlAttribute = geocacheAttributes.firstChild(); !xmlAttribute.isNull(); xmlAttribute=xmlAttribute.nextSibling())
+    for(QDomNode xmlAttribute = geocacheAttributes.firstChild(); !xmlAttribute.isNull(); xmlAttribute = xmlAttribute.nextSibling())
     {
         quint8 id = xmlAttribute.attributes().namedItem("id").nodeValue().toUInt();
         if(id >= geocache.attributeMeanings.size())
@@ -641,7 +658,7 @@ void CGisItemWpt::readGcExt(const QDomNode& xmlCache)
         }
 
         qint8 intvalue = xmlAttribute.attributes().namedItem("inc").nodeValue().toUInt();
-        geocache.attributes[id]=(intvalue == 1);
+        geocache.attributes[id] = (intvalue == 1);
         if(id == 42) //42 is the code for 'Needs maintenance' and it only appears, when there attribute is set
         {
             geocache.needsMaintenance = true;
@@ -1168,5 +1185,4 @@ void CDeviceGarmin::createAdventureFromProject(IGisProject * project, const QStr
     out << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << endl;
     out << doc.toString();
     file.close();
-
 }
