@@ -1,7 +1,7 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
-    Copyright (C) 2019 Henri Hornburg   hrnbg@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2017 Norbert Truchsess <norbert.truchsess@t-online.de>
+    Copyright (C) 2019 Henri Hornburg <hrnbg@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -178,7 +178,7 @@ bool IGisProject::askBeforClose()
     {
         {
             CCanvasCursorLock cursorLock(Qt::ArrowCursor, __func__);
-            res = QMessageBox::question(CMainWindow::getBestWidgetForParent(), tr("Save project?"), tr("<h3>%1</h3>The project was changed. Save before closing it?").arg(getName()), QMessageBox::Save|QMessageBox::No|QMessageBox::Abort, QMessageBox::No);
+            res = QMessageBox::question(CMainWindow::getBestWidgetForParent(), tr("Save project?"), tr("<h3>%1</h3>The project was changed. Save before closing it?").arg(getName()), QMessageBox::Save | QMessageBox::No | QMessageBox::Abort, QMessageBox::No);
         }
 
         if(res == QMessageBox::Save)
@@ -389,7 +389,7 @@ void IGisProject::updateItems()
             if(progress.wasCanceled())
             {
                 QString msg = tr("<h3>%1</h3>Did that take too long for you? Do you want to skip correlation of tracks and waypoints for this project in the future?").arg(getNameEx());
-                int res = QMessageBox::question(&progress, tr("Canceled correlation..."), msg, QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes);
+                int res = QMessageBox::question(&progress, tr("Canceled correlation..."), msg, QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
                 noCorrelation = res == QMessageBox::Yes;
                 break;
             }
@@ -721,7 +721,7 @@ bool IGisProject::delItemByKey(const IGisItem::key_t& key, QMessageBox::Standard
 {
     for(int i = childCount(); i > 0; i--)
     {
-        IGisItem * item = dynamic_cast<IGisItem*>(child(i-1));
+        IGisItem * item = dynamic_cast<IGisItem*>(child(i - 1));
         if(nullptr == item )
         {
             continue;
@@ -732,7 +732,7 @@ bool IGisProject::delItemByKey(const IGisItem::key_t& key, QMessageBox::Standard
             if(last != QMessageBox::YesToAll)
             {
                 QString msg = tr("Are you sure you want to delete '%1' from project '%2'?").arg(item->getName()).arg(text(CGisListWks::eColumnName));
-                last = QMessageBox::question(CMainWindow::getBestWidgetForParent(), tr("Delete..."), msg, QMessageBox::YesToAll|QMessageBox::Cancel|QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok);
+                last = QMessageBox::question(CMainWindow::getBestWidgetForParent(), tr("Delete..."), msg, QMessageBox::YesToAll | QMessageBox::Cancel | QMessageBox::Ok | QMessageBox::No, QMessageBox::Ok);
                 if((last == QMessageBox::No) || (last == QMessageBox::Cancel))
                 {
                     // as each item in the project has to be unique, we can stop searching.
@@ -761,7 +761,7 @@ void IGisProject::editItemByKey(const IGisItem::key_t& key)
 {
     for(int i = childCount(); i > 0; i--)
     {
-        IGisItem * item = dynamic_cast<IGisItem*>(child(i-1));
+        IGisItem * item = dynamic_cast<IGisItem*>(child(i - 1));
         if(nullptr == item)
         {
             continue;
@@ -775,7 +775,7 @@ void IGisProject::editItemByKey(const IGisItem::key_t& key)
 }
 
 
-void IGisProject::insertCopyOfItem(IGisItem * item, int off, int& lastResult)
+void IGisProject::insertCopyOfItem(IGisItem * item, int off, CSelectCopyAction::result_e& lastResult)
 {
     bool clone = false;
     IGisItem::key_t key = item->getKey();
@@ -785,7 +785,7 @@ void IGisProject::insertCopyOfItem(IGisItem * item, int off, int& lastResult)
     IGisItem * item2 = getItemByKey(key);
     if(item2 != nullptr)
     {
-        int result = lastResult;
+        CSelectCopyAction::result_e result = lastResult;
         if(lastResult == CSelectCopyAction::eResultNone)
         {
             CSelectCopyAction dlg(item, item2, CMainWindow::getBestWidgetForParent());
@@ -1086,6 +1086,7 @@ void IGisProject::sortItems()
     QList<IGisItem*> ovls;
 
     QList<QTreeWidgetItem*> items = takeChildren();
+    QList<QTreeWidgetItem*> others; //For example Search
     for(QTreeWidgetItem* item : items)
     {
         CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(item);
@@ -1115,6 +1116,8 @@ void IGisProject::sortItems()
             ovls << ovl;
             continue;
         }
+
+        others << item;
     }
 
     sortItems(trks);
@@ -1123,6 +1126,7 @@ void IGisProject::sortItems()
     sortItems(ovls);
 
     items.clear();
+    items << others;
     for(IGisItem * item : trks)
     {
         items << item;
@@ -1141,6 +1145,11 @@ void IGisProject::sortItems()
     }
 
     addChildren(items);
+    if(projectFilter != nullptr)
+    {
+        projectFilter->showLineEdit(&projectSearch);
+    }
+    applyFilters();
 }
 
 
@@ -1169,10 +1178,26 @@ void IGisProject::sortItems(QList<IGisItem *> &items) const
     case IGisProject::eSortFolderTime:
         qSort(items.begin(), items.end(), &sortByTime);
         break;
+
+    case IGisProject::eSortFolderRating:
+        qSort(items.begin(), items.end(), [](IGisItem* a, IGisItem* b){return a->getRating() > b->getRating();});
+        break;
     }
 }
 
-void IGisProject::filter(CSearch& search)
+void IGisProject::setProjectFilter(const CSearch& search)
+{
+    projectSearch = search;
+    applyFilters();
+}
+
+void IGisProject::setWorkspaceFilter(const CSearch& search)
+{
+    workspaceSearch = search;
+    applyFilters();
+}
+
+void IGisProject::applyFilters()
 {
     const int N = childCount();
 
@@ -1184,7 +1209,10 @@ void IGisProject::filter(CSearch& search)
             continue;
         }
 
-        item->setHidden(!search.getSearchResult(item));//get search result returns wether the object matches
+        bool projectFilterResult = projectSearch.getSearchResult(item);
+        bool workspaceFilterResult = workspaceSearch.getSearchResult(item);
+
+        item->setHidden(!(projectFilterResult && workspaceFilterResult));//get search result returns wether the object matches
     }
 }
 
@@ -1215,3 +1243,27 @@ void IGisProject::gainUserFocus(bool yes)
         keyUserFocus.clear();
     }
 }
+
+CProjectFilterItem* IGisProject::filterProject(bool filter)
+{
+    if(filter)
+    {
+        if(projectFilter == nullptr)
+        {
+            projectFilter = new CProjectFilterItem(this);
+            insertChild(0, projectFilter);
+        }
+        //Set expanded anyways to show that search exists
+        projectFilter->showLineEdit();
+        setExpanded(true);
+    }
+    else
+    {
+        removeChild(projectFilter);
+        delete projectFilter;
+        projectFilter = nullptr;
+        projectSearch = CSearch("");
+    }
+    sortItems();
+    return projectFilter;
+}
