@@ -1,5 +1,5 @@
 /**********************************************************************************************
-    Copyright (C) 2016 Michel Durand zero@cms123.fr
+    Copyright (C) 2016 Michel Durand <zero@cms123.fr>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ CTcxProject::CTcxProject(const QString &filename, const IGisProject * project, I
     *(IGisProject*)this = *project;
     blockUpdateItems(project->blockUpdateItems());
 
-    int res     = CSelectCopyAction::eResultNone;
+    CSelectCopyAction::result_e res = CSelectCopyAction::eResultNone;
     const int N = project->childCount();
     for(int n = 0; n < N; n++)
     {
