@@ -1,5 +1,5 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ CTwoNavProject::CTwoNavProject(const QString &filename, const IGisProject * proj
     setIcon(CGisListWks::eColumnIcon, QIcon("://icons/32x32/2NavProject.png"));
     *(IGisProject*)this = *project;
 
-    int res     = CSelectCopyAction::eResultNone;
+    CSelectCopyAction::result_e res = CSelectCopyAction::eResultNone;
     const int N = project->childCount();
     for(int n = 0; n < N; n++)
     {
@@ -246,7 +246,7 @@ bool CTwoNavProject::load(const QString& filename)
 {
     QDir dir(filename);
 
-    QStringList entries = dir.entryList(QDir::NoDotAndDotDot|QDir::Dirs|QDir::Files);
+    QStringList entries = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs | QDir::Files);
     for(const QString &entry : entries)
     {
         QFileInfo fi(entry);
