@@ -1,5 +1,5 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ CDetailsTrk::CDetailsTrk(CGisItemTrk& trk)
     setupUi(this);
     QPixmap icon(14, 14);
     const int N = IGisItem::getColorMap().count();
-    for(int i=0; i < N; ++i)
+    for(int i = 0; i < N; ++i)
     {
         const IGisItem::color_t& color = IGisItem::getColorMap()[i];
         icon.fill(color.color);
@@ -108,8 +108,8 @@ CDetailsTrk::CDetailsTrk(CGisItemTrk& trk)
     treeTrackPointInfo->setTrack(&trk);
 
     plot1 = new CPlotProfile(&trk, trk.limitsGraph1, IPlot::eModeNormal, this);
-    plot2 = new CPlot(&trk, trk.limitsGraph2, this);
-    plot3 = new CPlot(&trk, trk.limitsGraph3, this);
+    plot2 = new CPlot(&trk, trk.limitsGraph2, IPlot::eModeNormal, this);
+    plot3 = new CPlot(&trk, trk.limitsGraph3, IPlot::eModeNormal, this);
 
     for(IPlot *plot : { static_cast<IPlot*>(plot1), static_cast<IPlot*>(plot2), static_cast<IPlot*>(plot3) })
     {
