@@ -1,5 +1,5 @@
 /**********************************************************************************************
-    Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2008 Oliver Eichler <oliver.eichler@gmx.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,10 +18,10 @@
 **********************************************************************************************/
 #include "CMainWindow.h"
 #include "GeoMath.h"
+#include "units/CUnitAviation.h"
 #include "units/CUnitImperial.h"
 #include "units/CUnitMetric.h"
 #include "units/CUnitNautic.h"
-#include "units/CUnitAviation.h"
 
 #include <proj_api.h>
 #include <QtWidgets>
@@ -422,7 +422,7 @@ const char * IUnit::tblTimezone[] =
     0
 };
 
-const int N_TIMEZONES = sizeof(IUnit::tblTimezone)/sizeof(const char*);
+const int N_TIMEZONES = sizeof(IUnit::tblTimezone) / sizeof(const char*);
 
 const QRegExp IUnit::reCoord1("^\\s*([N|S]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s+([E|W|O]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s*$");
 
@@ -434,23 +434,54 @@ const QRegExp IUnit::reCoord4("^\\s*([N|S]){1}\\s*([0-9]+)\\W+([0-9]+)\\W+([0-9]
 
 const QRegExp IUnit::reCoord5("^\\s*([-0-9]+\\.[0-9]+)([N|S])\\s+([-0-9]+\\.[0-9]+)([W|E])\\s*$");
 
-IUnit::IUnit(const type_e &type, const QString& baseunit, const qreal basefactor, const QString& speedunit, const qreal speedfactor, QObject * parent)
+IUnit::IUnit(const type_e &type, const QString& baseUnit, const qreal baseFactor, const QString& speedUnit, const qreal speedFactor, const QString &elevationUnit, const qreal elevationFactor, QObject * parent)
     : QObject(parent)
     , type(type)
-    , baseunit(baseunit)
-    , basefactor(basefactor)
-    , speedunit(speedunit)
-    , speedfactor(speedfactor)
+    , baseUnit(baseUnit)
+    , baseFactor(baseFactor)
+    , speedUnit(speedUnit)
+    , speedFactor(speedFactor)
+    , elevationUnit(elevationUnit)
+    , elevationFactor(elevationFactor)
 {
     //there can be only one...
     delete m_self;
     m_self = this;
 }
 
+void IUnit::meter2elevation(qreal meter, QString& val, QString& unit) const
+{
+    if(meter == NOFLOAT || meter == NOINT)
+    {
+        val  = "-";
+        unit.clear();
+    }
+    else
+    {
+        val.sprintf("%1.0f", meter * elevationFactor);
+        unit = elevationUnit;
+    }
+}
+
+void IUnit::meter2elevation(qreal meter, qreal& val, QString& unit) const
+{
+    if(meter == NOFLOAT)
+    {
+        val  = NOFLOAT;
+        unit.clear();
+    }
+    else
+    {
+        val = meter * elevationFactor;
+        unit = elevationUnit;
+    }
+}
+
+
 void IUnit::meter2base(qreal meter, QString& val, QString& unit) const
 {
-    unit = baseunit;
-    val.sprintf("%1.0f", meter * basefactor);
+    unit = baseUnit;
+    val.sprintf("%1.0f", meter * baseFactor);
 }
 
 bool IUnit::convert(qreal &value, QString &unit, const QString &targetUnit)
@@ -536,6 +567,13 @@ bool IUnit::convert(qreal &value, QString &unit, const QString &targetUnit)
 
 void IUnit::slope2string(qreal slope, QString &val, QString &unit)
 {
+    if(slope == NOFLOAT)
+    {
+        val = "-";
+        unit = "";
+        return;
+    }
+
     switch(slopeMode)
     {
     case eSlopeDegrees:
@@ -544,7 +582,7 @@ void IUnit::slope2string(qreal slope, QString &val, QString &unit)
         break;
 
     case eSlopePercent:
-        val.sprintf("%.0f", qTan(qDegreesToRadians(slope))*100.0);
+        val.sprintf("%.0f", qTan(qDegreesToRadians(slope)) * 100.0);
         unit = "%";
         break;
     }
@@ -574,7 +612,7 @@ void IUnit::slope2unit(qreal slope, qreal &val, QString &unit)
         break;
 
     case eSlopePercent:
-        val = qTan(qDegreesToRadians(slope))*100.0;
+        val = qTan(qDegreesToRadians(slope)) * 100.0;
         unit = "%";
         break;
     }
@@ -614,8 +652,8 @@ void IUnit::meter2speed(qreal meter, QString& val, QString& unit) const
         return;
     }
 
-    val.sprintf("%2.2f", meter * speedfactor);
-    unit = speedunit;
+    val.sprintf("%2.2f", meter * speedFactor);
+    unit = speedUnit;
 }
 
 void IUnit::meter2speed(qreal meter, qreal& val, QString& unit) const
@@ -627,8 +665,8 @@ void IUnit::meter2speed(qreal meter, qreal& val, QString& unit) const
         return;
     }
 
-    val = meter * speedfactor;
-    unit = speedunit;
+    val = meter * speedFactor;
+    unit = speedUnit;
 }
 
 void IUnit::seconds2time(quint32 ttime, QString& val, QString& unit) const
@@ -680,7 +718,7 @@ QDateTime IUnit::parseTimestamp(const QString &timetext, int& tzoffset)
     i = timetext.indexOf(".");
     if (i != NOIDX)
     {
-        if(timetext[i+1] == '0')
+        if(timetext[i + 1] == '0')
         {
             format += ".zzz";
         }
@@ -765,7 +803,7 @@ QString IUnit::datetime2string(const QDateTime& time, bool shortDate, const QPoi
     }
 
     QDateTime tmp = time.toTimeZone(tz);
-    return tmp.toString((shortDate|useShortFormat) ? Qt::ISODate : Qt::SystemLocaleLongDate);
+    return tmp.toString((shortDate | useShortFormat) ? Qt::ISODate : Qt::SystemLocaleLongDate);
 }
 
 QByteArray IUnit::pos2timezone(const QPointF& pos)
@@ -945,7 +983,7 @@ bool IUnit::isValidCoordString(const QString& str)
     return false;
 }
 
-QMap<QString, qreal> IUnit::timeToMKSMap={
+QMap<QString, qreal> IUnit::timeToMKSMap = {
     {"s", 1.0},
     {"min", 60.0},
     {"h", 3600.0},
@@ -954,41 +992,41 @@ QMap<QString, qreal> IUnit::timeToMKSMap={
     {"ч", 3600.0},
 };
 
-QMap<QString, qreal> IUnit::distanceToMKSMap={
+QMap<QString, qreal> IUnit::distanceToMKSMap = {
     {"m", 1.0},
     {"km", 1000.0},
-    {"mi", 1.0/CUnitImperial::milePerMeter},
-    {"ft", 1.0/CUnitImperial::footPerMeter},
+    {"mi", 1.0 / CUnitImperial::milePerMeter},
+    {"ft", 1.0 / CUnitImperial::footPerMeter},
     {"м", 1.0},
     {"км", 1000.0},
 };
 
-QMap<QString, qreal> IUnit::speedToMKSMap={
+QMap<QString, qreal> IUnit::speedToMKSMap = {
     {"m/s", 1.0},
-    {"m/min", 1.0/60},
-    {"m/h", 1.0/3600},
+    {"m/min", 1.0 / 60},
+    {"m/h", 1.0 / 3600},
     {"km/s", 1000.0},
-    {"km/min", 1000.0/60},
-    {"km/h", 1000.0/3600},
-    {"mi/s", 1.0/CUnitImperial::milePerMeter},
-    {"mi/min", 1.0/(CUnitImperial::milePerMeter*60)},
-    {"mi/h", 1.0/(CUnitImperial::milePerMeter*3600)},
-    {"ft/s", 1.0/CUnitImperial::footPerMeter},
-    {"ft/min", 1.0/(CUnitImperial::footPerMeter*60)},
-    {"ft/h", 1.0/(CUnitImperial::footPerMeter*3600)},
+    {"km/min", 1000.0 / 60},
+    {"km/h", 1000.0 / 3600},
+    {"mi/s", 1.0 / CUnitImperial::milePerMeter},
+    {"mi/min", 1.0 / (CUnitImperial::milePerMeter*60)},
+    {"mi/h", 1.0 / (CUnitImperial::milePerMeter*3600)},
+    {"ft/s", 1.0 / CUnitImperial::footPerMeter},
+    {"ft/min", 1.0 / (CUnitImperial::footPerMeter*60)},
+    {"ft/h", 1.0 / (CUnitImperial::footPerMeter*3600)},
     {"м/с", 1.0},
-    {"м/мин", 1.0/60},
-    {"м/ч", 1.0/3600},
+    {"м/мин", 1.0 / 60},
+    {"м/ч", 1.0 / 3600},
     {"км/с", 1000.0},
-    {"км/мин", 1000.0/60},
-    {"км/ч", 1000.0/3600},
+    {"км/мин", 1000.0 / 60},
+    {"км/ч", 1000.0 / 3600},
 };
 
-QMap<QString, qreal> IUnit::areaToMKSMap={
+QMap<QString, qreal> IUnit::areaToMKSMap = {
     {"m²", 1.0},
-    {"km²", 1000.0*1000},
-    {"mi²", 1.0/(CUnitImperial::milePerMeter*CUnitImperial::milePerMeter)},
-    {"ft²", 1.0/(CUnitImperial::footPerMeter*CUnitImperial::footPerMeter)},
+    {"km²", 1000.0 * 1000},
+    {"mi²", 1.0 / (CUnitImperial::milePerMeter*CUnitImperial::milePerMeter)},
+    {"ft²", 1.0 / (CUnitImperial::footPerMeter*CUnitImperial::footPerMeter)},
     {"м²", 1.0},
-    {"км²", 1000.0*1000},
+    {"км²", 1000.0 * 1000},
 };
