@@ -33,7 +33,13 @@ class CGdalFile
 {
     Q_DECLARE_TR_FUNCTIONS(CGdalFile)
 public:
-    CGdalFile();
+    enum type_e
+    {
+        eTypePixel,
+        eTypeProj
+    };
+
+    CGdalFile(type_e type);
     virtual ~CGdalFile() = default;
 
     bool getIsValid() const
@@ -48,6 +54,8 @@ protected:
     virtual void load(const QString& filename);
     virtual void unload();
 
+    type_e type;
+
     GDALDataset * dataset = nullptr;
 
     /// number of color bands used by the *vrt
@@ -84,6 +92,9 @@ protected:
     QTransform trFwd;
     QTransform trInv;
 
+    QTransform trFwdProj;
+    QTransform trInvProj;
+
     QString proj4str;
 
     projPJ pjsrc = nullptr;
