@@ -1,5 +1,5 @@
 /**********************************************************************************************
-   Copyright (C) 2015 Ivo Kronenberg
+   Copyright (C) 2015 Ivo Kronenberg <>
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 static QString relTranslationDir = "Resources/translations"; // app
 static QString relGdalDir        = "Resources/gdal"; // app
 static QString relProjDir        = "Resources/proj"; // app
+static QString relHelpDir        = "Resources/help"; // app
 static QString relBinDir         = "Tools"; // app
 
 static QString relLogDir         = "Library/Logs"; // home
@@ -138,3 +139,9 @@ void CAppSetupMac::migrateDirContent(QString dest)
         }
     }
 }
+
+QString CAppSetupMac::helpFile()
+{
+    QDir dirHelp(getApplicationDir(relHelpDir));
+    return dirHelp.absoluteFilePath("QMTHelp.qhc");
+}
